--###############################################################################
--#
--#    Licensed Materials - Property of IBM
--#
--#    (C) Copyright IBM Corp. 2008, 2009
--#    All Rights Reserved
--#
--#    remove_tnsqm.sql 1.1
--#    
--#
--#############################################################################
--#
--# 1.1 - Added support for TNSQM 4.1.2/TBSM 4.2 integration
--#
--#############################################################################
--#
--# This script is used to uninstall the TNSQM correlations and related
--# objects from an OMNIbus 7.x ObjectServer. It removes:
--#   - Automations (triggers and a trigger group)
--#   - Additional Fields in alerts.status
--#
--# To remove the TNSQM correlation support run one of the following
--# platform-dependent commands:
--#
--# Unix:
--#   $OMNIHOME/bin/nco_sql -server <objectserver_name> -user <username>
--#   -password <password> < <path_to_file>/remove_tnsqm.sql
--#
--# Windows:
--#   %OMNIHOME%\bin\redist\isql.exe -S <objectserver name> -U <username> -P
--#   <password> -i <path_to_file>\remove_tnsqm.sql
--#
--#############################################################################

-- Remove required fields from alerts.status

alter table alerts.status drop column TNSQM_SQMSLO;
alter table alerts.status drop column TNSQM_RuleName;
alter table alerts.status drop column TNSQM_RuleID;
alter table alerts.status drop column TNSQM_KQIWeight;
alter table alerts.status drop column TNSQM_KQIWeightUnit;
go

-- Add the TNSQM automation

create or replace trigger group tnsqm_triggers;
go

alter trigger deduplication set priority 2;

create or replace trigger tnsqm_update_fields_on_dedup
group tnsqm_triggers
priority 1
comment 'Update Fields on Deduplication for TNSQM events'
before reinsert on alerts.status
for each row
begin
	if (new.Class = 86005)
	then		
	
		set old.TNSQM_PrevSeverity = old.Severity;
		set old.TNSQM_PrevKQIValue = old.TNSQM_KQIValue;
		
		set old.Severity= new.Severity; 
		set old.TNSQM_KQIValue = new.TNSQM_KQIValue;
		
		set old.TNSQM_StartTime = new.TNSQM_StartTime;
		set old.TNSQM_EndTime = new.TNSQM_EndTime;
		set old.TNSQM_Schedule = new.TNSQM_Schedule;

		set old.TNSQM_Accuracy = new.TNSQM_Accuracy;
		
		set old.TNSQM_RuleCondition = new.TNSQM_RuleCondition;
		
		set old.TNSQM_User = new.TNSQM_User;
		
		set old.TNSQM_Clause = new.TNSQM_Clause;
		set old.TNSQM_ClauseName = new.TNSQM_ClauseName;
		
		set old.TNSQM_Node = new.TNSQM_Node;
		set old.TNSQM_Port = new.TNSQM_Port;

	end if;
end;
go

